@@ -25,19 +25,16 @@
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <libgnomeui/gnome-file-entry.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include "gtk-utils.h"
-#include "window.h"
+#include "fr-window.h"
 
 
-#define PROP_GLADE_FILE "file_roller.glade"
+#define GLADE_FILE "password.glade"
 
 
 typedef struct {
 	GladeXML  *gui;
-	FRWindow  *window;
+	FrWindow  *window;
 	GtkWidget *dialog;
 	GtkWidget *pw_password_entry;
 } DialogData;
@@ -46,24 +43,10 @@ typedef struct {
 /* called when the main dialog is closed. */
 static void
 destroy_cb (GtkWidget  *widget,
-            DialogData *data)
+	    DialogData *data)
 {
 	g_object_unref (data->gui);
-        g_free (data);
-}
-
-
-static void
-ok_clicked_cb (GtkWidget  *widget,
-	       DialogData *data)
-{
-	char *password;
-
-	password = _gtk_entry_get_locale_text (GTK_ENTRY (data->pw_password_entry));
-	window_set_password (data->window, password);
-	g_free (password);
-
-	gtk_widget_destroy (data->dialog);
+	g_free (data);
 }
 
 
@@ -72,15 +55,19 @@ response_cb (GtkWidget  *dialog,
 	     int         response_id,
 	     DialogData *data)
 {
+	char *password;
+
 	switch (response_id) {
 	case GTK_RESPONSE_OK:
-		ok_clicked_cb (NULL, data);
+		password = _gtk_entry_get_locale_text (GTK_ENTRY (data->pw_password_entry));
+		fr_window_set_password (data->window, password);
+		g_free (password);
 		break;
-	case GTK_RESPONSE_CLOSE:
 	default:
-		gtk_widget_destroy (data->dialog);
 		break;
 	}
+
+	gtk_widget_destroy (data->dialog);
 }
 
 
@@ -88,44 +75,45 @@ void
 dlg_password (GtkWidget *widget,
 	      gpointer   callback_data)
 {
-        DialogData       *data;
-	FRWindow         *window = callback_data;
+	FrWindow   *window = callback_data;
+	DialogData *data;
 
-        data = g_new (DialogData, 1);
+	data = g_new0 (DialogData, 1);
 	data->window = window;
-	data->gui = glade_xml_new (GLADEDIR "/" PROP_GLADE_FILE , NULL, NULL);
+	data->gui = glade_xml_new (GLADEDIR "/" GLADE_FILE , NULL, NULL);
 	if (!data->gui) {
-                g_warning ("Could not find " PROP_GLADE_FILE "\n");
-                return;
-        }
+		g_warning ("Could not find " GLADE_FILE "\n");
+		return;
+	}
 
-        /* Get the widgets. */
+	/* Get the widgets. */
 
-        data->dialog = glade_xml_get_widget (data->gui, "password_dialog");
+	data->dialog = glade_xml_get_widget (data->gui, "password_dialog");
 	data->pw_password_entry = glade_xml_get_widget (data->gui, "pw_password_entry");
 
 	/* Set widgets data. */
 
-	if (window->password != NULL)
-		_gtk_entry_set_locale_text (GTK_ENTRY (data->pw_password_entry), window->password);
+	_gtk_entry_set_locale_text (GTK_ENTRY (data->pw_password_entry), fr_window_get_password (window));
 
 	/* Set the signals handlers. */
 
-	g_signal_connect (G_OBJECT (data->dialog), 
+	g_signal_connect (G_OBJECT (data->dialog),
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (data->dialog), 
+	g_signal_connect (G_OBJECT (data->dialog),
 			  "response",
 			  G_CALLBACK (response_cb),
 			  data);
 
 	/* Run dialog. */
 
-        gtk_window_set_transient_for (GTK_WINDOW (data->dialog), 
-				      GTK_WINDOW (window->app));
-        gtk_window_set_modal         (GTK_WINDOW (data->dialog), TRUE);
+	gtk_widget_grab_focus (data->pw_password_entry);
+	if (GTK_WIDGET_REALIZED (window))
+		gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
+					      GTK_WINDOW (window));
+	gtk_window_set_modal (GTK_WINDOW (data->dialog), TRUE);
 
 	gtk_widget_show (data->dialog);
 }
