@@ -26,8 +26,6 @@
 #include <time.h>
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "file-data.h"
 #include "file-utils.h"
@@ -35,65 +33,66 @@
 #include "fr-command.h"
 #include "fr-command-zip.h"
 
-#define EMPTY_ARCHIVE_WARNING        "zipfile is empty"
-#define EMPTY_ARCHIVE_WARNING_LENGTH 16
+#define EMPTY_ARCHIVE_WARNING        "Empty zipfile."
 
-static void fr_command_zip_class_init  (FRCommandZipClass *class);
-static void fr_command_zip_init        (FRCommand         *afile);
+static void fr_command_zip_class_init  (FrCommandZipClass *class);
+static void fr_command_zip_init        (FrCommand         *afile);
 static void fr_command_zip_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
 
 static time_t
-mktime_from_string (char *date_s, 
-		    char *time_s)
+mktime_from_string (char *datetime_s)
 {
-	struct tm   tm = {0, };
-	char      **fields;
+	struct tm  tm = {0, };
+	char      *date;
+	char      *time;
+	char      *year;
+	char      *month;
+	char      *day;
+	char      *hour;
+	char      *min;
+	char      *sec;
+
+	tm.tm_isdst = -1;
 
 	/* date */
 
-	fields = g_strsplit (date_s, "-", 3);
-	if (fields[0] != NULL) {
-		tm.tm_mon = atoi (fields[0]) - 1;
-		if (fields[1] != NULL) {
-			tm.tm_mday = atoi (fields[1]);
-			if (fields[2] != NULL) { 
-				/* warning : this will work until 2075 ;) */
-				int y = atoi (fields[2]);
-				if (y >= 75)
-					tm.tm_year = atoi (fields[2]);
-				else
-					tm.tm_year = 100 + atoi (fields[2]);
-			}
-		}
-	}
-	g_strfreev (fields);
+	date = datetime_s;
+	year = g_strndup (date, 4);
+	month = g_strndup (date + 4, 2);
+	day = g_strndup (date + 6, 2);
+	tm.tm_year = atoi (year) - 1900;
+	tm.tm_mon = atoi (month) - 1;
+	tm.tm_mday = atoi (day);
+	g_free (year);
+	g_free (month);
+	g_free (day);
 
 	/* time */
 
-	fields = g_strsplit (time_s, ":", 3);
-	if (fields[0] != NULL) {
-		tm.tm_hour = atoi (fields[0]);
-		if (fields[1] != NULL) {
-			tm.tm_min = atoi (fields[1]);
-			if (fields[2] != NULL)
-				tm.tm_sec = atoi (fields[2]);
-		}
-	}
-	g_strfreev (fields);
+	time = datetime_s + 9;
+	hour = g_strndup (time, 2);
+	min = g_strndup (time + 2, 2);
+	sec = g_strndup (time + 4, 2);
+	tm.tm_hour = atoi (hour);
+	tm.tm_min = atoi (min);
+	tm.tm_sec = atoi (sec);
+	g_free(hour);
+	g_free(min);
+	g_free(sec);
 
 	return mktime (&tm);
 }
 
 
 static char *
-fr_command_zip_escape (FRCommand     *comm,
+fr_command_zip_escape (FrCommand     *comm,
 		       const char    *str)
 {
 	char *estr;
@@ -105,7 +104,7 @@ fr_command_zip_escape (FRCommand     *comm,
 	g_free (estr);
 
 	return estr2;
-	
+
 }
 
 
@@ -119,9 +118,9 @@ zip_escape (const char *str)
 static char*
 prepend_path_separator (const char *str)
 {
-	if (*str == '-' || g_str_has_prefix (str, "\\-")) 
+	if (*str == '-' || g_str_has_prefix (str, "\\-"))
 		return g_strconcat (".", G_DIR_SEPARATOR_S, str, NULL);
-	else 
+	else
 		return g_strdup (str);
 }
 
@@ -134,17 +133,17 @@ prepend_path_separator_zip_escape (const char *str)
 	tmp2 = prepend_path_separator (str);
 	tmp1 = zip_escape (tmp2);
 	g_free (tmp2);
-	
+
 	return tmp1;
 }
 
 
 static void
-list__process_line (char     *line, 
+list__process_line (char     *line,
 		    gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *comm = FR_COMMAND (data);
+	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 	gint         line_l;
@@ -161,20 +160,24 @@ list__process_line (char     *line,
 	if (line_l == 0)
 		return;
 
-	if (line_l > EMPTY_ARCHIVE_WARNING_LENGTH) 
-		if (strcmp (line + line_l - EMPTY_ARCHIVE_WARNING_LENGTH, 
-			    EMPTY_ARCHIVE_WARNING) == 0) {
-			FR_COMMAND_ZIP (comm)->is_empty = TRUE;
-			return;
-		}
+	if (strcmp (line, EMPTY_ARCHIVE_WARNING) == 0) {
+		FR_COMMAND_ZIP (comm)->is_empty = TRUE;
+		return;
+	}
+
+	/* ignore lines that do not describe a file or a
+	 * directory. */
+	if ((line[0] != '?') && (line[0] != 'd') && (line[0] != '-'))
+		return;
 
 	/**/
 
 	fdata = file_data_new ();
 
 	fields = split_line (line, 7);
-	fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
-	fdata->modified = mktime_from_string (fields[4], fields[5]);
+	fdata->size = g_ascii_strtoull (fields[3], NULL, 10);
+	fdata->modified = mktime_from_string (fields[6]);
+	fdata->encrypted = (*fields[4] == 'B') || (*fields[4] == 'T');
 	g_strfreev (fields);
 
 	/* Full path */
@@ -191,19 +194,22 @@ list__process_line (char     *line,
 
 	fdata->link = NULL;
 
-	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
+	fdata->dir = line[0] == 'd';
+	if (fdata->dir)
+		fdata->name = dir_name_from_path (fdata->full_path);
+	else
+		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
 	else
-		comm->file_list = g_list_prepend (comm->file_list, fdata);
+		fr_command_add_file (comm, fdata);
 }
 
 
 static void
-add_filename_arg (FRCommand *comm) 
+add_filename_arg (FrCommand *comm)
 {
 	char *temp = prepend_path_separator (comm->e_filename);
 	fr_process_add_arg (comm->process, temp);
@@ -212,7 +218,7 @@ add_filename_arg (FRCommand *comm)
 
 
 static void
-add_password_arg (FRCommand     *comm,
+add_password_arg (FrCommand     *comm,
 		  const char    *password,
 		  gboolean       always_specify)
 {
@@ -236,18 +242,17 @@ add_password_arg (FRCommand     *comm,
 
 
 static void
-fr_command_zip_list (FRCommand *comm)
+fr_command_zip_list (FrCommand  *comm,
+		     const char *password)
 {
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      list__process_line,
 				      comm);
 
 	fr_process_begin_command (comm->process, "unzip");
-	fr_process_add_arg (comm->process, "-qq");
-	fr_process_add_arg (comm->process, "-v");
-	fr_process_add_arg (comm->process, "-l");
+	fr_process_add_arg (comm->process, "-ZTs");
 	add_filename_arg (comm);
 	fr_process_end_command (comm->process);
 	fr_process_start (comm->process);
@@ -255,10 +260,10 @@ fr_command_zip_list (FRCommand *comm)
 
 
 static void
-process_line__common (char     *line, 
+process_line__common (char     *line,
 		      gpointer  data)
 {
-	FRCommand  *comm = FR_COMMAND (data);
+	FrCommand  *comm = FR_COMMAND (data);
 
 	if (line == NULL)
 		return;
@@ -266,14 +271,14 @@ process_line__common (char     *line,
 	fr_command_message (comm, line);
 
 	if (comm->n_files != 0) {
-		double fraction = (double) comm->n_file++ / (comm->n_files+1);
+		double fraction = (double) ++comm->n_file / (comm->n_files + 1);
 		fr_command_progress (comm, fraction);
 	}
 }
 
 
 static void
-fr_command_zip_add (FRCommand     *comm,
+fr_command_zip_add (FrCommand     *comm,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
@@ -282,13 +287,13 @@ fr_command_zip_add (FRCommand     *comm,
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
 	fr_process_begin_command (comm->process, "zip");
 
-	if (base_dir != NULL) 
+	if (base_dir != NULL)
 		fr_process_set_working_dir (comm->process, base_dir);
 
 	/* preserve links. */
@@ -323,12 +328,12 @@ fr_command_zip_add (FRCommand     *comm,
 
 
 static void
-fr_command_zip_delete (FRCommand *comm,
+fr_command_zip_delete (FrCommand *comm,
 		       GList     *file_list)
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
@@ -347,7 +352,7 @@ fr_command_zip_delete (FRCommand *comm,
 
 
 static void
-fr_command_zip_extract (FRCommand  *comm,
+fr_command_zip_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -357,12 +362,12 @@ fr_command_zip_extract (FRCommand  *comm,
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
 	fr_process_begin_command (comm->process, "unzip");
-	
+
 	if (dest_dir != NULL) {
 		char *e_dest_dir = fr_command_escape (comm, dest_dir);
 		fr_process_add_arg (comm->process, "-d");
@@ -396,7 +401,7 @@ fr_command_zip_extract (FRCommand  *comm,
 
 
 static void
-fr_command_zip_test (FRCommand   *comm,
+fr_command_zip_test (FrCommand   *comm,
 		     const char  *password)
 {
 	fr_process_begin_command (comm->process, "unzip");
@@ -408,30 +413,48 @@ fr_command_zip_test (FRCommand   *comm,
 
 
 static void
-fr_command_zip_handle_error (FRCommand   *comm, 
+fr_command_zip_handle_error (FrCommand   *comm,
 			     FRProcError *error)
 {
-	if (error->type == FR_PROC_ERROR_GENERIC) {
+	if (error->type == FR_PROC_ERROR_COMMAND_ERROR) {
 		if (error->status <= 1)
 			error->type = FR_PROC_ERROR_NONE;
 		else if ((error->status == 82) || (error->status == 5))
 			error->type = FR_PROC_ERROR_ASK_PASSWORD;
+		else {
+			GList *output;
+			GList *scan;
+			
+			if (comm->action == FR_ACTION_TESTING_ARCHIVE)
+				output = comm->process->raw_output;
+			else
+				output = comm->process->raw_error;
+			
+			for (scan = g_list_last (output); scan; scan = scan->prev) {
+				char *line = scan->data;
+				
+				if (strstr (line, "incorrect password") != NULL) {
+					error->type = FR_PROC_ERROR_ASK_PASSWORD;
+					break;
+				}
+			}
+		}
 	}
 }
 
 
-static void 
-fr_command_zip_class_init (FRCommandZipClass *class)
+static void
+fr_command_zip_class_init (FrCommandZipClass *class)
 {
-        GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+	GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
+	FrCommandClass *afc;
 
-        parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	parent_class = g_type_class_peek_parent (class);
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_zip_finalize;
 
-        afc->list           = fr_command_zip_list;
+	afc->list           = fr_command_zip_list;
 	afc->add            = fr_command_zip_add;
 	afc->delete         = fr_command_zip_delete;
 	afc->extract        = fr_command_zip_extract;
@@ -441,14 +464,15 @@ fr_command_zip_class_init (FRCommandZipClass *class)
 	afc->escape         = fr_command_zip_escape;
 }
 
- 
-static void 
-fr_command_zip_init (FRCommand *comm)
+
+static void
+fr_command_zip_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_ZIP;
 
-	comm->propAddCanUpdate             = TRUE; 
-	comm->propAddCanReplace            = TRUE; 
+	comm->propAddCanUpdate             = TRUE;
+	comm->propAddCanReplace            = TRUE;
+	comm->propAddCanStoreFolders       = TRUE;
 	comm->propExtractCanAvoidOverwrite = TRUE;
 	comm->propExtractCanSkipOlder      = TRUE;
 	comm->propExtractCanJunkPaths      = TRUE;
@@ -459,14 +483,14 @@ fr_command_zip_init (FRCommand *comm)
 }
 
 
-static void 
+static void
 fr_command_zip_finalize (GObject *object)
 {
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_COMMAND_ZIP (object));
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (FR_IS_COMMAND_ZIP (object));
 
 	/* Chain up */
-        if (G_OBJECT_CLASS (parent_class)->finalize)
+	if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -474,17 +498,17 @@ fr_command_zip_finalize (GObject *object)
 GType
 fr_command_zip_get_type ()
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (FRCommandZipClass),
+	if (! type) {
+		GTypeInfo type_info = {
+			sizeof (FrCommandZipClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_zip_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandZip),
+			sizeof (FrCommandZip),
 			0,
 			(GInstanceInitFunc) fr_command_zip_init
 		};
@@ -493,17 +517,17 @@ fr_command_zip_get_type ()
 					       "FRCommandZip",
 					       &type_info,
 					       0);
-        }
+	}
 
-        return type;
+	return type;
 }
 
 
-FRCommand *
-fr_command_zip_new (FRProcess  *process,
+FrCommand *
+fr_command_zip_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path ("zip") &&
 	    !is_program_in_path ("unzip")) {
