@@ -207,8 +207,9 @@ GList *    fr_window_get_folder_tree_selection    (FrWindow    *window,
 GList *    fr_window_get_selection                (FrWindow    *window,
 		  	 			   gboolean     from_sidebar,
 		  	 			   char       **return_base_dir);				     		   
-GtkListStore *
+GtkTreeModel *
 	   fr_window_get_list_store               (FrWindow    *window);
+void       fr_window_find                         (FrWindow    *window);	   
 void       fr_window_select_all                   (FrWindow    *window);
 void       fr_window_unselect_all                 (FrWindow    *window);
 void       fr_window_set_sort_type                (FrWindow    *window,
